@@ -296,7 +296,7 @@ class Client(commandServer, encrypt, Desktop):
             addon = ",nomapposix"
         cache_method = self.clVars.Get('cl_cifs_cache')
         domain = self.get_server_domainname(host)
-        cifs_mount_vers = self.clVars.Get('cl_cifs_mount_vers')
+        cl_cifs_mount_vers = self.clVars.Get('cl_cifs_mount_vers')
         if not uid is None:
             # mount by uid
             p = process(mountCmd, "-t", "cifs", "-o",
